@@ -18,46 +18,48 @@ def build_index(dirbook) :
     from time import strftime,localtime
     if not os.path.isdir(dirbook) :
         return
-    with open(os.path.join(dirbook,"index.html"),"w") as fnew :
-        fnew.write("<html>\n")
-        fnew.write("<head>\n")
-        fnew.write("  <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">\n")
-        fnew.write("  <title>Novels</title>\n")
-        fnew.write("</head>\n")
-        fnew.write("<body style=\"background-color: #EAF2F8;color: #000000;\">\n")
-        fnew.write("<table border=1 style=\"border-collapse:collapse;\">\n")
-        tmstr = strftime("%H:%M",localtime())
-        fnew.write("<tr style=\"background-color:{};\"><td><a href=\".\">{}({})</a></td><td></td></tr>\n".format("#C9D08E","Index",tmstr))
-        colors = ["#EFD3FD","#FDEFD3","#F6FDD3"]
-        ic=0
-        for d in sorted(os.listdir(dirbook),reverse=True,key=lambda x:os.path.getmtime(x)) :
-            if not any([c for c in d if ord(c) > 127]) :
-                continue
-            rd = os.path.join(dirbook,d)
-            if not os.path.isdir(rd) :
-                continue
-            fidx = os.path.join(rd,"index.html")
-            if not os.path.exists(fidx) :
-                continue
-            ic += 1
-            with open(fidx,"r") as f :
-                cnt = 0
-                for ln in reversed(f.readlines()) :
-                    if cnt < 2 and re.search(r"td.*href.*html",ln) :
-                        ln = re.sub("href=","href={}/".format(d),ln)
-                        ln = ln.replace("<tr>","")
-                        ln = ln.replace("</tr>","")
-                        ln = ln.replace("\"","")
-                        bgcolor = colors [ic % len(colors)]
-                        if cnt == 0 :
-                            fnew.write("<tr style=\"background-color:{};\">\n<td><a href=\"{}\">{}</a></td>\n".format(bgcolor,d,d))
-                        else :
-                            tmstr = strftime("%D %H:%M",localtime(os.path.getmtime(rd))) 
-                            fnew.write("<tr style=\"color:{};background-color:{};\">\n<td align=\"right\">{}</td>\n".format("#00BB00",bgcolor,tmstr))
-                        fnew.write(ln+"</tr>\n")
-                        cnt += 1
-        fnew.write("</table>\n")
-        fnew.write("</html>")
+    content = ""
+    content +=("<html>\n")
+    content +=("<head>\n")
+    content +=("  <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">\n")
+    content +=("  <title>Novels</title>\n")
+    content +=("</head>\n")
+    content +=("<body style=\"background-color: #212121;color: #B5B5B5;\">\n")
+    content +=("<table border=1 style=\"border-collapse:collapse;\">\n")
+    tmstr = strftime("%H:%M",localtime())
+    content +=("<tr style=\"background-color:{};\"><td><a href=\".\">{}({})</a></td><td></td></tr>\n".format("#374FB2","Index",tmstr))
+    colors = ["#C0C0C0","#B6B6B6","#C6C6C6"]
+    ic=0
+    for d in sorted(os.listdir(dirbook),reverse=True,key=lambda x:os.path.getmtime(os.path.join(dirbook,x))) :
+        if not any([c for c in d if ord(c) > 127]) :
+            continue
+        rd = os.path.join(dirbook,d)
+        if not os.path.isdir(rd) :
+            continue
+        fidx = os.path.join(rd,"index.html")
+        if not os.path.exists(fidx) :
+            continue
+        ic += 1
+        with open(fidx,"r") as f :
+            cnt = 0
+            for ln in reversed(f.readlines()) :
+                if cnt < 2 and re.search(r"td.*href.*html",ln) :
+                    ln = re.sub("href=","href={}/".format(d),ln)
+                    ln = ln.replace("<tr>","")
+                    ln = ln.replace("</tr>","")
+                    ln = ln.replace("\"","")
+                    bgcolor = colors [ic % len(colors)]
+                    if cnt == 0 :
+                        content +=("<tr style=\"background-color:{};\">\n<td><a href=\"{}\">{}</a></td>\n".format(bgcolor,d,d))
+                    else :
+                        tmstr = strftime("%D %H:%M",localtime(os.path.getmtime(rd))) 
+                        content +=("<tr style=\"color:{};background-color:{};\">\n<td align=\"right\">{}</td>\n".format("#00BB00",bgcolor,tmstr))
+                    content +=(ln+"</tr>\n")
+                    cnt += 1
+    content +=("</table>\n")
+    content +=("</html>\n")
+    with open(os.path.join(dirbook,"index.html"),"w") as fw  :
+        fw.write(content)
     
 
 def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
@@ -79,7 +81,7 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
             header = """
 <meta name="viewport" content="width=device-width, initial-scale=1.0">
 <title>book_title</title>
-<body style="background-color: #EAF2F8;color: #000000;">
+<body style="background-color: #212121;color: #B5B5B5;">
 <table style="border-collapse:collapse">
 """
             f.write(header.replace("book_title",title))
@@ -106,7 +108,7 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
     if debug :
         print(rtext)
     chapters = list()
-    for m in re.findall(r"(<td|<dd|<li).*?>\s*<a\s+href=\"(\S*?\d+\.(htm|html))\".*?>\s*(.*?)\s*</a>",rtext,re.DOTALL) :
+    for m in re.findall(r"(<td|<dd|<li)[^<>]*?>\s*<a\s+href=\"(\S*?\d+\.(htm|html))\".*?>\s*(.*?)\s*</a>",rtext,re.DOTALL) :
         url=m[1].split("/")[-1]
         m2 = re.search(r"(\d+)",url)
         if m2 :
@@ -209,7 +211,7 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False) :
         ps = """<script type="text/javascript"> var preview_page = "prevpg"; var next_page = "nextpg"; var index_page = "index.html"; function jumpPage() { if (event.keyCode==37) location=preview_page; if (event.keyCode==39) location=next_page; if (event.keyCode==13) location=index_page; } document.onkeydown=jumpPage; </script> </head>\n"""
         rtext += ps.replace("prevpg",prevpg).replace("nextpg",nextpg)
         rtext += "</head>\n"
-        rtext += "<body style=\"background-color: #EAF2F8;color: #000000;\">\n"
+        rtext += "<body style=\"background-color: #212121;color: #B5B5B5;\">\n"
         rtext += "<a href=\"index.html\">INDEX of {}</a>\n".format(title)
         rtext += "<br/>\n"*2
         rtext += "<a href=\"{}\">PREV CHAPTER</a>\n".format(prevpg)
